#!/bin/sh

#
# indent.sh - la meme chose que fold, avec moins d'options
#
# Usage : indent.sh [ -n <num> ] [ -latex ] [ -docbook ] [ -h | --help ]
#
# Description :
# indent.sh fait la meme chose que fold, avec moins d'options (fold -s -w
# $MaxCarParLigne).
# Mais pour la version LaTeX, fold  ne fait pas de traitement particulier
# (ne pas indenter pour les lignes commencant par %).
# En plus l'exemple suivant issue de fold ne me plait pas :
#
# ./fold -s -w 60
# .nf
# <emphasis>bien</emphasis> meilleure allure en PostScript, PDF ou HTML en
# raison de la typographie utilisee.
# <emphasis>bien</emphasis> meilleure allure en PostScript,
# PDF ou HTML en raison
# de la typographie utilisee.
# .fi
# Alors que indent.sh fait :
# ./indent.sh 60
# .nf
# <emphasis>bien</emphasis> meilleure allure en PostScript, PDF ou HTML en raison
# de la typographie utilisee.
# <emphasis>bien</emphasis> meilleure allure en PostScript,
# PDF ou HTML en raison de la typographie utilisee.
# .fi
# Le texte continue apres "en raison" (pas de retour a la ligne).
#
# Options :
# -n <num> precise le nombre de caracteres pas ligne devant etre affiches
# (60 par defaut)
# -latex : formate un fichier LaTeX
# -docbook : formate un fichier docbook
# -h | --help : affiche l'aide
#
# Voir aussi :
# fold(1)
#

MaxCarParLigne=60

#
# Par defaut, on affiche au maximum 60 caracteres par ligne, ou le premier
# argument passe au script si il y en a un.
#

while [ -n "$1" ]
do
    case "$1" in
        -n) MaxCarParLigne=$2 ; shift ;;
        -latex) LaTeX="y" ;;
        -docbook) DocBook="y" ;;
        -h|--help)
            echo "Usage : `basename $0` [ -n <num> ] [ -latex ] [ -docbook ] [ -h | --help ]"
            exit 0 ;;
    esac
    shift
done

NombreCaractere=0

TraiteLaTeX ()
{

#
# Ne pas appliquer le traitement sur le texte en "verbatim",
#

    if echo "$ligne" | grep "\\\begin *{verbatim}" > /dev/null
    then
        echo "$ligne"
        while ! echo "$ligne" | grep "\\\end *{verbatim}" > /dev/null
        do
            read -r ligne && echo "$ligne"
        done
        read ligne
    fi
    [ -z "$ligne" ] && echo

#
# si cette ligne contient un commentaire LaTeX (ie. elle contient le
# caractere '%' sans '\' devant), ne pas appliquer le traitement et passer
# directement a la ligne suivante,
#

## grep "[^\\]%" ne marche po...
    echo "$ligne" | grep "%" > /dev/null && (! echo "$ligne" |  grep "\\\\%" > /dev/null) && echo "$ligne" && continue
#        echo "$ligne" | grep "[^\\]%" > /dev/null && echo "$ligne" && continue

}

TraiteDocBook ()
{

#
# Ne pas appliquer le traitement sur le texte en "verbatim",
#

    if echo "$ligne" | grep "<programlisting " > /dev/null
    then
        echo "$ligne"
        while ! echo "$ligne" | grep "</programlisting>" > /dev/null
        do
            read -r ligne && echo "$ligne"
        done
        read ligne
    fi
    [ -z "$ligne" ] && echo
}

#
# Pour chaque ligne lue sur l'entree standard...
#

while read -r ligne
do
    if [ -z "$ligne" ]
    then
        echo -e "\n"
        NombreCaractere=0
        continue
    fi

[ "$LaTeX" = "y" ] && TraiteLaTeX
[ "$DocBook" = "y" ] && TraiteDocBook

#
# pour chaque mot de la ligne,
#

        for mot in $ligne
        do
            NombreCarMot=`echo $mot | wc -c`
            NombreCaractere=`expr $NombreCaractere + $NombreCarMot`

#
# si le nombre de caracteres depasse NombreCaractere, nouvelle ligne,
#

            if [ $NombreCaractere -ge $MaxCarParLigne ]
            then
                NombreCaractere=$NombreCarMot
                echo
            fi

#
# et on affiche ce mot.
#

        echo -n "$mot "
        done
done

echo
